==> ZenTaoPMS-ipd1.2-php7.0.zip: zentaopms/module/compile/lang/en.php <==
<?php
$lang->compile->common      = 'Compile';
$lang->compile->browse      = 'History';
$lang->compile->logs        = 'Log';
$lang->compile->syncCompile = 'Interface: Sync Compiles.';

$lang->compile->id          = 'ID';
$lang->compile->name        = 'Name';
$lang->compile->buildType   = 'Engine';
$lang->compile->status      = 'Status';
$lang->compile->time        = 'Time';
$lang->compile->result      = 'Result';
$lang->compile->refresh     = 'Refresh';
$lang->compile->job         = 'Job';
$lang->compile->queue       = 'Queue';
$lang->compile->atTime      = 'Execution Time';
$lang->compile->testtask    = 'Testtask';
$lang->compile->tag         = 'Tag';
$lang->compile->times       = 'Times';
$lang->compile->repo        = 'Repo';
$lang->compile->createdBy   = 'Created By';
$lang->compile->createdDate = 'Created Date';
$lang->compile->updateDate  = 'Update Date';
$lang->compile->deleted     = 'Deleted';

$lang->compile->statusList['success']     = 'Done';
$lang->compile->statusList['failure']     = 'Failed';
$lang->compile->statusList['created']     = 'Created';
$lang->compile->statusList['pending']     = 'Pending';
$lang->compile->statusList['running']     = 'Running';
$lang->compile->statusList['building']    = 'Building';
$lang->compile->statusList['create_fail'] = 'Failed to create';
$lang->compile->statusList['timeout']     = 'Timeout';
$lang->compile->statusList['canceled']    = 'Canceled';
$lang->compile->statusList['failed']      = 'Build failed';
$lang->compile->statusList['skipped']     = 'Skipped';

$lang->compile->featureBar['browse']['job']     = 'List';
$lang->compile->featureBar['browse']['compile'] = 'History';

==> ZenTaoPMS-ipd2.6.1-php7.2_7.4.zip: zentaopms/module/compile/lang/en.php <==
<?php
$lang->compile->common      = 'Compile';
$lang->compile->browse      = 'History';
$lang->compile->logs        = 'Log';
$lang->compile->syncCompile = 'Interface: Sync Compiles.';

$lang->compile->id          = 'ID';
$lang->compile->name        = 'Name';
$lang->compile->buildType   = 'Engine';
$lang->compile->status      = 'Status';
$lang->compile->time        = 'Time';
$lang->compile->result      = 'Result';
$lang->compile->refresh     = 'Refresh';
$lang->compile->job         = 'Job';
$lang->compile->queue       = 'Queue';
$lang->compile->atTime      = 'Execution Time';
$lang->compile->testtask    = 'Testtask';
$lang->compile->tag         = 'Tag';
$lang->compile->times       = 'Times';
$lang->compile->repo        = 'Repo';
$lang->compile->createdBy   = 'Created By';
$lang->compile->createdDate = 'Created Date';
$lang->compile->updateDate  = 'Update Date';
$lang->compile->deleted     = 'Deleted';

$lang->compile->statusList['success']     = 'Done';
$lang->compile->statusList['failure']     = 'Failed';
$lang->compile->statusList['created']     = 'Waiting';
$lang->compile->statusList['pending']     = 'Pending';
$lang->compile->statusList['running']     = 'Running';
$lang->compile->statusList['building']    = 'Building';
$lang->compile->statusList['create_fail'] = 'Failed to create';
$lang->compile->statusList['timeout']     = 'Timeout';
$lang->compile->statusList['canceled']    = 'Canceled';
$lang->compile->statusList['failed']      = 'Build failed';

$lang->compile->featureBar['browse']['job']     = 'List';
$lang->compile->featureBar['browse']['compile'] = 'History';
